==> azhtmlwebui_0.7.7.jar: org/parg/azureus/plugins/azhtmlwebui/templates/js/sorttable.js <==
addEvent(window, "load", sortables_init);

var SORT_COLUMN_INDEX;

function sortables_init() {
    // Find all tables with class sortable and make them sortable
    if (!document.getElementsByTagName) return;
    tbls = document.getElementsByTagName("table");
    for (ti=0;ti<tbls.length;ti++) {
        thisTbl = tbls[ti];
        if (((' '+thisTbl.className+' ').indexOf("azcontent") != -1) && (thisTbl.id)) {
            //initTable(thisTbl.id);
            ts_makeSortable(thisTbl);
        }
    }
}

function ts_makeSortable(table) {
    if (table.rows && table.rows.length > 0) {
        var firstRow = table.rows[0];
    }
    if (!firstRow) return;
    
    // We have a first row: assume it's the header, and make its contents clickable links
    for (var i=0;i<firstRow.cells.length;i++) {
        var cell = firstRow.cells[i];
        var txt = ts_getInnerText(cell);
        if ( txt == "#" ) {
        	cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow">&nbsp;<img src="images/up.gif" border="0"  width="8" height="8"></span></a>';
//        	cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow">&nbsp;&uarr;</span></a>';
        } else {
        	if ( txt != "More" ) cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow"></span></a>';
        }
    }
}

function ts_getInnerText(el) {
	if (typeof el == "string") return el;
	if (typeof el == "undefined") { return el };
	if (el.innerText) return el.innerText;	//Not needed but it is faster
	var str = "";
	
	var cs = el.childNodes;
	var l = cs.length;
	for (var i = 0; i < l; i++) {
		switch (cs[i].nodeType) {
			case 1: //ELEMENT_NODE
				str += ts_getInnerText(cs[i]);
				break;
			case 3:	//TEXT_NODE
				str += cs[i].nodeValue;
				break;
		}
	}
	return str;
}

function ts_resortTable(lnk) {
    // get the span
    var span;
    for (var ci=0;ci<lnk.childNodes.length;ci++) {
        if (lnk.childNodes[ci].tagName && lnk.childNodes[ci].tagName.toLowerCase() == 'span') span = lnk.childNodes[ci];
    }
    var spantext = ts_getInnerText(span);
    var td = lnk.parentNode;
    var column = td.cellIndex;
    var table = getParent(td,'TABLE');
    
    // Work out a type for the column
    if (table.rows.length <= 1) return;
    var itm = ts_getInnerText(table.rows[1].cells[column]);
    sortfn = ts_sort_caseinsensitive;
    if (itm.match(/^\d\d[\/-]\d\d[\/-]\d\d\d\d$/)) sortfn = ts_sort_date;
    if (itm.match(/^\d\d[\/-]\d\d[\/-]\d\d$/)) sortfn = ts_sort_date;
    if (itm.match(/^[?$]/)) sortfn = ts_sort_currency;
    if (itm.match(/^[\d\.]+$/)) sortfn = ts_sort_numeric;
    if (itm.match(/^[\d\.]+( | k| M| G| T)B$/)) sortfn = ts_sort_size;
    if (itm.match(/^[\d\.]+( | k| M| G| T)B\/s$/)) sortfn = ts_sort_speed;
    if (itm.match(/[\d\.]+%/) || itm.match(/N\/A/)) sortfn = ts_sort_percent;
    
    SORT_COLUMN_INDEX = column;
    var firstRow = new Array();
    var newRows = new Array();
    var oldRows = new Array();
    for (i=0;i<table.rows[0].length;i++) { firstRow[i] = table.rows[0][i]; }
    for (j=1;j<table.rows.length;j++) { newRows[j-1] = table.rows[j]; }

    oldRows = newRows;
    newRows.sort(sortfn);
    
    if (span.getAttribute("sortdir") == 'up') {
        ARROW = '&nbsp;<img src="images/up.gif" border="0" width="8" height="8">';
//        ARROW = '&nbsp;&uarr;';
        span.setAttribute('sortdir','down');
    } else {
       ARROW = '&nbsp;<img src="images/down.gif" border="0" width="8" height="8">';
//        ARROW = '&nbsp;&darr;';
        newRows.reverse();
        span.setAttribute('sortdir','up');
    }
    
    // We appendChild rows that already exist to the tbody, so it moves them rather than creating new ones
    // don't do sortbottom rows
    for (i=0;i<newRows.length;i++) { 
    	if (!newRows[i].className || (newRows[i].className && (newRows[i].className.indexOf('sortbottom') == -1))) {	
    		table.tBodies[0].appendChild(newRows[i]);
    	}
    }
    // do sortbottom rows only
    for (i=0;i<newRows.length;i++) { 
    	if (newRows[i].className && (newRows[i].className.indexOf('sortbottom') != -1)) {
    		table.tBodies[0].appendChild(newRows[i]);
    	}
    }
    
    for (i=0;i<newRows.length;i++) { 
    		if (i % 2) {
    		
    			newRows[i].setAttribute( 'onMouseOver', "className='trtorrent_hover'" );
    			newRows[i].onmouseover = function() { this.className='trtorrent_hover'; }	// IE

    			if (oldRows[i].className == 'trtorrent_active' || oldRows[i].className == 'trtorrent_odd_active') {
    				newRows[i].setAttribute('class', 'trtorrent_active');
    				newRows[i].setAttribute('className', 'trtorrent_active');			// IE
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_active'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_active'; }			// IE
    			} else {
    				newRows[i].setAttribute( 'class', 'trtorrent' );
    				newRows[i].setAttribute( 'className', 'trtorrent' );						// IE
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent'; }			// IE
    			}
    			
    		} else {
    			
    			newRows[i].setAttribute( 'onMouseOver', "className='trtorrent_hover'" );
    			newRows[i].onmouseover = function() { this.className='trtorrent_hover'; }	// IE

	    		if (oldRows[i].className == 'trtorrent_active' || oldRows[i].className == 'trtorrent_odd_active') {
	    			newRows[i].setAttribute('class', 'trtorrent_odd_active');
	    			newRows[i].setAttribute('className', 'trtorrent_odd_active');
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_odd_active'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_odd_active'; }			// IE
	    		} else {
	    			newRows[i].setAttribute( 'class', 'trtorrent_odd' );
	    			newRows[i].setAttribute( 'className', 'trtorrent_odd' );
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_odd'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_odd'; }			// IE
	    		}
    		}
    }
    
    // Delete any other arrows there may be showing
    var allspans = document.getElementsByTagName("span");
    for (var ci=0;ci<allspans.length;ci++) {
        if (allspans[ci].className == 'sortarrow') {
            if (getParent(allspans[ci],"table") == getParent(lnk,"table")) { // in the same table as us?
                allspans[ci].innerHTML = '';
            }
        }
    }
        
    span.innerHTML = ARROW;
}

function getParent(el, pTagName) {
	if (el == null) return null;
	else if (el.nodeType == 1 && el.tagName.toLowerCase() == pTagName.toLowerCase())	// Gecko bug, supposed to be uppercase
		return el;
	else
		return getParent(el.parentNode, pTagName);
}
function ts_sort_date(a,b) {
    // y2k notes: two digit years less than 50 are treated as 20XX, greater than 50 are treated as 19XX
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (aa.length == 10) {
        dt1 = aa.substr(6,4)+aa.substr(3,2)+aa.substr(0,2);
    } else {
        yr = aa.substr(6,2);
        if (parseInt(yr) < 50) { yr = '20'+yr; } else { yr = '19'+yr; }
        dt1 = yr+aa.substr(3,2)+aa.substr(0,2);
    }
    if (bb.length == 10) {
        dt2 = bb.substr(6,4)+bb.substr(3,2)+bb.substr(0,2);
    } else {
        yr = bb.substr(6,2);
        if (parseInt(yr) < 50) { yr = '20'+yr; } else { yr = '19'+yr; }
        dt2 = yr+bb.substr(3,2)+bb.substr(0,2);
    }
    if (dt1==dt2) return 0;
    if (dt1<dt2) return -1;
    return 1;
}

function ts_sort_currency(a,b) { 
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'');
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'');
    return parseFloat(aa) - parseFloat(bb);
}

function ts_sort_numeric(a,b) { 
    aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]));
    if (isNaN(aa)) aa = 0;
    bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX])); 
    if (isNaN(bb)) bb = 0;
    return aa-bb;
}

function ts_sort_size(a,b) { 
    a_unit = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_unit = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (a_unit.match(/B$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (a_unit.match(/kB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (a_unit.match(/MB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (a_unit.match(/GB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (a_unit.match(/TB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    if (b_unit.match(/B$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (b_unit.match(/kB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (b_unit.match(/MB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (b_unit.match(/GB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (b_unit.match(/TB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    return aa-bb;
}

function ts_sort_speed(a,b) { 
    a_unit = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_unit = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (a_unit.match(/B\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (a_unit.match(/kB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (a_unit.match(/MB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (a_unit.match(/GB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (a_unit.match(/TB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    if (b_unit.match(/B\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (b_unit.match(/kB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (b_unit.match(/MB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (b_unit.match(/GB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (b_unit.match(/TB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    return aa-bb;
}

function ts_sort_percent(a,b) {
    a_content = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_content = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
	if (a_content.match(/N\/A/) && b_content.match(/N\/A/)) return 0;
	if (a_content.match(/N\/A/) && !b_content.match(/N\/A/)) return -1;
	if (!a_content.match(/N\/A/) && b_content.match(/N\/A/)) return 1;
	a1 = a_content.substring(0,a_content.indexOf('%'));
	b1 = b_content.substring(0,b_content.indexOf('%'));
    aa = parseFloat(a1.replace(/[^0-9.]/g,''));
    bb = parseFloat(b1.replace(/[^0-9.]/g,''));
	return aa-bb;
}

function ts_sort_caseinsensitive(a,b) {
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).toLowerCase();
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).toLowerCase();
    if (aa==bb) return 0;
    if (aa<bb) return -1;
    return 1;
}

function ts_sort_default(a,b) {
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (aa==bb) return 0;
    if (aa<bb) return -1;
    return 1;
}


function addEvent(elm, evType, fn, useCapture)
// addEvent and removeEvent
// cross-browser event handling for IE5+,  NS6 and Mozilla
// By Scott Andrew
{
  if (elm.addEventListener){
    elm.addEventListener(evType, fn, useCapture);
    return true;
  } else if (elm.attachEvent){
    var r = elm.attachEvent("on"+evType, fn);
    return r;
  } else {
    alert("Handler could not be removed");
  }
}

==> azhtmlwebui2_1.0.2.jar: org/parg/azureus/plugins/azhtmlwebui/templates/js/sorttable.js <==
addEvent(window, "load", sortables_init);

var SORT_COLUMN_INDEX;

function sortables_init() {
    // Find all tables with class sortable and make them sortable
    if (!document.getElementsByTagName) return;
    tbls = document.getElementsByTagName("table");
    for (ti=0;ti<tbls.length;ti++) {
        thisTbl = tbls[ti];
        if (((' '+thisTbl.className+' ').indexOf("azcontent") != -1) && (thisTbl.id) && (' '+thisTbl.className+' ').indexOf("azcontent_") == -1 ) {
            //initTable(thisTbl.id);
            ts_makeSortable(thisTbl);
        }
    }
}

function ts_makeSortable(table) {
    if (table.rows && table.rows.length > 0) {
        var firstRow = table.rows[0];
    }
    if (!firstRow) return;
    
    // We have a first row: assume it's the header, and make its contents clickable links
    for (var i=0;i<firstRow.cells.length;i++) {
        var cell = firstRow.cells[i];
        var txt = ts_getInnerText(cell);
        if ( txt == "#" ) {
        	cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow">&nbsp;<img src="images/up.gif" border="0"  width="8" height="8"></span></a>';
//        	cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow">&nbsp;&uarr;</span></a>';
        } else {
        	if ( txt != "More" ) cell.innerHTML = '<a href="#" class="sortheader" onclick="ts_resortTable(this);return false;">'+txt+'<span class="sortarrow"></span></a>';
        }
    }
}

function ts_getInnerText(el) {
	if (typeof el == "string") return el;
	if (typeof el == "undefined") { return el };
	if (el.innerText) return el.innerText;	//Not needed but it is faster
	var str = "";
	
	var cs = el.childNodes;
	var l = cs.length;
	for (var i = 0; i < l; i++) {
		switch (cs[i].nodeType) {
			case 1: //ELEMENT_NODE
				str += ts_getInnerText(cs[i]);
				break;
			case 3:	//TEXT_NODE
				str += cs[i].nodeValue;
				break;
		}
	}
	return str;
}

function ts_resortTable(lnk) {
    // get the span
    var span;
    for (var ci=0;ci<lnk.childNodes.length;ci++) {
        if (lnk.childNodes[ci].tagName && lnk.childNodes[ci].tagName.toLowerCase() == 'span') span = lnk.childNodes[ci];
    }
    var spantext = ts_getInnerText(span);
    var td = lnk.parentNode;
    var column = td.cellIndex;
    var table = getParent(td,'TABLE');
    
    // Work out a type for the column
    if (table.rows.length <= 1) return;
    var itm = ts_getInnerText(table.rows[1].cells[column]);
    sortfn = ts_sort_caseinsensitive;
    if (itm.match(/^\d\d[\/-]\d\d[\/-]\d\d\d\d$/)) sortfn = ts_sort_date;
    if (itm.match(/^\d\d[\/-]\d\d[\/-]\d\d$/)) sortfn = ts_sort_date;
    if (itm.match(/^[?$]/)) sortfn = ts_sort_currency;
    if (itm.match(/^[\d\.]+$/)) sortfn = ts_sort_numeric;
    if (itm.match(/^[\d\.]+( | k| M| G| T)B$/)) sortfn = ts_sort_size;
    if (itm.match(/^[\d\.]+( | k| M| G| T)B\/s$/)) sortfn = ts_sort_speed;
    if (itm.match(/[\d\.]+%/) || itm.match(/N\/A/)) sortfn = ts_sort_percent;
    
    SORT_COLUMN_INDEX = column;
    var firstRow = new Array();
    var newRows = new Array();
    var oldRows = new Array();
    for (i=0;i<table.rows[0].length;i++) { firstRow[i] = table.rows[0][i]; }
    for (j=1;j<table.rows.length;j++) { newRows[j-1] = table.rows[j]; }

    oldRows = newRows;
    newRows.sort(sortfn);
    
    if (span.getAttribute("sortdir") == 'up') {
        ARROW = '&nbsp;<img src="images/up.gif" border="0" width="8" height="8">';
//        ARROW = '&nbsp;&uarr;';
        span.setAttribute('sortdir','down');
    } else {
       ARROW = '&nbsp;<img src="images/down.gif" border="0" width="8" height="8">';
//        ARROW = '&nbsp;&darr;';
        newRows.reverse();
        span.setAttribute('sortdir','up');
    }
    
    // We appendChild rows that already exist to the tbody, so it moves them rather than creating new ones
    // don't do sortbottom rows
    for (i=0;i<newRows.length;i++) { 
    	if (!newRows[i].className || (newRows[i].className && (newRows[i].className.indexOf('sortbottom') == -1))) {	
    		table.tBodies[0].appendChild(newRows[i]);
    	}
    }
    // do sortbottom rows only
    for (i=0;i<newRows.length;i++) { 
    	if (newRows[i].className && (newRows[i].className.indexOf('sortbottom') != -1)) {
    		table.tBodies[0].appendChild(newRows[i]);
    	}
    }
    
    for (i=0;i<newRows.length;i++) { 
    		if (i % 2) {
    		
    			newRows[i].setAttribute( 'onMouseOver', "className='trtorrent_hover'" );
    			newRows[i].onmouseover = function() { this.className='trtorrent_hover'; }	// IE

    			if (oldRows[i].className == 'trtorrent_active' || oldRows[i].className == 'trtorrent_odd_active') {
    				newRows[i].setAttribute('class', 'trtorrent_active');
    				newRows[i].setAttribute('className', 'trtorrent_active');			// IE
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_active'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_active'; }			// IE
    			} else {
    				newRows[i].setAttribute( 'class', 'trtorrent' );
    				newRows[i].setAttribute( 'className', 'trtorrent' );						// IE
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent'; }			// IE
    			}
    			
    		} else {
    			
    			newRows[i].setAttribute( 'onMouseOver', "className='trtorrent_hover'" );
    			newRows[i].onmouseover = function() { this.className='trtorrent_hover'; }	// IE

	    		if (oldRows[i].className == 'trtorrent_active' || oldRows[i].className == 'trtorrent_odd_active') {
	    			newRows[i].setAttribute('class', 'trtorrent_odd_active');
	    			newRows[i].setAttribute('className', 'trtorrent_odd_active');
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_odd_active'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_odd_active'; }			// IE
	    		} else {
	    			newRows[i].setAttribute( 'class', 'trtorrent_odd' );
	    			newRows[i].setAttribute( 'className', 'trtorrent_odd' );
    			
    				newRows[i].setAttribute( 'onMouseOut', "className='trtorrent_odd'" );
    				newRows[i].onmouseout = function() { this.className='trtorrent_odd'; }			// IE
	    		}
    		}
    }
    
    // Delete any other arrows there may be showing
    var allspans = document.getElementsByTagName("span");
    for (var ci=0;ci<allspans.length;ci++) {
        if (allspans[ci].className == 'sortarrow') {
            if (getParent(allspans[ci],"table") == getParent(lnk,"table")) { // in the same table as us?
                allspans[ci].innerHTML = '';
            }
        }
    }
        
    span.innerHTML = ARROW;
}

function getParent(el, pTagName) {
	if (el == null) return null;
	else if (el.nodeType == 1 && el.tagName.toLowerCase() == pTagName.toLowerCase())	// Gecko bug, supposed to be uppercase
		return el;
	else
		return getParent(el.parentNode, pTagName);
}
function ts_sort_date(a,b) {
    // y2k notes: two digit years less than 50 are treated as 20XX, greater than 50 are treated as 19XX
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (aa.length == 10) {
        dt1 = aa.substr(6,4)+aa.substr(3,2)+aa.substr(0,2);
    } else {
        yr = aa.substr(6,2);
        if (parseInt(yr) < 50) { yr = '20'+yr; } else { yr = '19'+yr; }
        dt1 = yr+aa.substr(3,2)+aa.substr(0,2);
    }
    if (bb.length == 10) {
        dt2 = bb.substr(6,4)+bb.substr(3,2)+bb.substr(0,2);
    } else {
        yr = bb.substr(6,2);
        if (parseInt(yr) < 50) { yr = '20'+yr; } else { yr = '19'+yr; }
        dt2 = yr+bb.substr(3,2)+bb.substr(0,2);
    }
    if (dt1==dt2) return 0;
    if (dt1<dt2) return -1;
    return 1;
}

function ts_sort_currency(a,b) { 
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'');
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'');
    return parseFloat(aa) - parseFloat(bb);
}

function ts_sort_numeric(a,b) { 
    aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]));
    if (isNaN(aa)) aa = 0;
    bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX])); 
    if (isNaN(bb)) bb = 0;
    return aa-bb;
}

function ts_sort_size(a,b) { 
    a_unit = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_unit = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (a_unit.match(/B$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (a_unit.match(/kB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (a_unit.match(/MB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (a_unit.match(/GB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (a_unit.match(/TB$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    if (b_unit.match(/B$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (b_unit.match(/kB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (b_unit.match(/MB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (b_unit.match(/GB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (b_unit.match(/TB$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    return aa-bb;
}

function ts_sort_speed(a,b) { 
    a_unit = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_unit = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (a_unit.match(/B\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (a_unit.match(/kB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (a_unit.match(/MB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (a_unit.match(/GB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (a_unit.match(/TB\/s$/)) aa = parseFloat(ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    if (b_unit.match(/B\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,''));
    if (b_unit.match(/kB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024;
    if (b_unit.match(/MB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024;
    if (b_unit.match(/GB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024;
    if (b_unit.match(/TB\/s$/)) bb = parseFloat(ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).replace(/[^0-9.]/g,'')) * 1024 * 1024 * 1024 * 1024;
    return aa-bb;
}

function ts_sort_percent(a,b) {
    a_content = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
	b_content = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
	if (a_content.match(/N\/A/) && b_content.match(/N\/A/)) return 0;
	if (a_content.match(/N\/A/) && !b_content.match(/N\/A/)) return -1;
	if (!a_content.match(/N\/A/) && b_content.match(/N\/A/)) return 1;
	a1 = a_content.substring(0,a_content.indexOf('%'));
	b1 = b_content.substring(0,b_content.indexOf('%'));
    aa = parseFloat(a1.replace(/[^0-9.]/g,''));
    bb = parseFloat(b1.replace(/[^0-9.]/g,''));
	return aa-bb;
}

function ts_sort_caseinsensitive(a,b) {
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]).toLowerCase();
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]).toLowerCase();
    if (aa==bb) return 0;
    if (aa<bb) return -1;
    return 1;
}

function ts_sort_default(a,b) {
    aa = ts_getInnerText(a.cells[SORT_COLUMN_INDEX]);
    bb = ts_getInnerText(b.cells[SORT_COLUMN_INDEX]);
    if (aa==bb) return 0;
    if (aa<bb) return -1;
    return 1;
}


function addEvent(elm, evType, fn, useCapture)
// addEvent and removeEvent
// cross-browser event handling for IE5+,  NS6 and Mozilla
// By Scott Andrew
{
  if (elm.addEventListener){
    elm.addEventListener(evType, fn, useCapture);
    return true;
  } else if (elm.attachEvent){
    var r = elm.attachEvent("on"+evType, fn);
    return r;
  } else {
    alert("Handler could not be removed");
  }
}
